pub struct L4Context {
pub src: SocketAddr,
pub dst: SocketAddr,
pub proto: usize,
pub offset: usize,
pub length: usize,
pub seq_no: u32,
pub ack_no: u32,
pub flags: u8,
pub reassembled: bool,
pub app_offset: Option<usize>,
}Expand description
Parsed transport-layer context from the packet used for connection tracking.
Fields
src: SocketAddrSource socket address.
dst: SocketAddrDestination socket address.
proto: usizeL4 protocol.
offset: usizeOffset into mbuf where L4 payload begins. If this segment is reassembled, this is the offset where new payload begins. None indicates that no new data. If segment has not been reassembled, this is offset after TCP header.
length: usizeLength of the payload in bytes.
seq_no: u32Raw sequence number of segment.
ack_no: u32Raw acknowledgment number of segment.
flags: u8TCP flags.
reassembled: boolTrue if packet has been reassembled, with corresponding
possible updates to offset.
app_offset: Option<usize>If segment contains application-layer body, its offset
into the payload (after offset, i.e. L4 headers).
None indicates no application-layer body.
Implementations